@@ -6,9 +6,7 @@ from django.test import TestCase
 from rest_framework.test import APIRequestFactory
 
 from rest_framework_simplejwt import authentication
-from rest_framework_simplejwt.exceptions import (
-    AuthenticationFailed, InvalidToken,
-)
+from rest_framework_simplejwt.exceptions import AuthenticationFailed, InvalidToken
 from rest_framework_simplejwt.models import TokenUser
 from rest_framework_simplejwt.settings import api_settings
 from rest_framework_simplejwt.tokens import AccessToken, SlidingToken
@@ -24,54 +22,60 @@ class TestJWTAuthentication(TestCase):
         self.factory = APIRequestFactory()
         self.backend = authentication.JWTAuthentication()
 
-        self.fake_token = b'TokenMcTokenface'
-        self.fake_header = b'Bearer ' + self.fake_token
+        self.fake_token = b"TokenMcTokenface"
+        self.fake_header = b"Bearer " + self.fake_token
 
     def test_get_header(self):
         # Should return None if no authorization header
-        request = self.factory.get('/test-url/')
+        request = self.factory.get("/test-url/")
         self.assertIsNone(self.backend.get_header(request))
 
         # Should pull correct header off request
-        request = self.factory.get('/test-url/', HTTP_AUTHORIZATION=self.fake_header)
+        request = self.factory.get("/test-url/", HTTP_AUTHORIZATION=self.fake_header)
         self.assertEqual(self.backend.get_header(request), self.fake_header)
 
         # Should work for unicode headers
-        request = self.factory.get('/test-url/', HTTP_AUTHORIZATION=self.fake_header.decode('utf-8'))
+        request = self.factory.get(
+            "/test-url/", HTTP_AUTHORIZATION=self.fake_header.decode("utf-8")
+        )
         self.assertEqual(self.backend.get_header(request), self.fake_header)
 
         # Should work with the x_access_token
-        with override_api_settings(AUTH_HEADER_NAME='HTTP_X_ACCESS_TOKEN'):
+        with override_api_settings(AUTH_HEADER_NAME="HTTP_X_ACCESS_TOKEN"):
             # Should pull correct header off request when using X_ACCESS_TOKEN
-            request = self.factory.get('/test-url/', HTTP_X_ACCESS_TOKEN=self.fake_header)
+            request = self.factory.get(
+                "/test-url/", HTTP_X_ACCESS_TOKEN=self.fake_header
+            )
             self.assertEqual(self.backend.get_header(request), self.fake_header)
 
             # Should work for unicode headers when using
-            request = self.factory.get('/test-url/', HTTP_X_ACCESS_TOKEN=self.fake_header.decode('utf-8'))
+            request = self.factory.get(
+                "/test-url/", HTTP_X_ACCESS_TOKEN=self.fake_header.decode("utf-8")
+            )
             self.assertEqual(self.backend.get_header(request), self.fake_header)
 
     def test_get_raw_token(self):
         # Should return None if header lacks correct type keyword
-        with override_api_settings(AUTH_HEADER_TYPES='JWT'):
+        with override_api_settings(AUTH_HEADER_TYPES="JWT"):
             reload(authentication)
             self.assertIsNone(self.backend.get_raw_token(self.fake_header))
         reload(authentication)
 
         # Should return None if an empty AUTHORIZATION header is sent
-        self.assertIsNone(self.backend.get_raw_token(b''))
+        self.assertIsNone(self.backend.get_raw_token(b""))
 
         # Should raise error if header is malformed
         with self.assertRaises(AuthenticationFailed):
-            self.backend.get_raw_token(b'Bearer one two')
+            self.backend.get_raw_token(b"Bearer one two")
 
         with self.assertRaises(AuthenticationFailed):
-            self.backend.get_raw_token(b'Bearer')
+            self.backend.get_raw_token(b"Bearer")
 
         # Otherwise, should return unvalidated token in header
         self.assertEqual(self.backend.get_raw_token(self.fake_header), self.fake_token)
 
         # Should return token if header has one of many valid token types
-        with override_api_settings(AUTH_HEADER_TYPES=('JWT', 'Bearer')):
+        with override_api_settings(AUTH_HEADER_TYPES=("JWT", "Bearer")):
             reload(authentication)
             self.assertEqual(
                 self.backend.get_raw_token(self.fake_header),
@@ -88,23 +92,25 @@ class TestJWTAuthentication(TestCase):
 
         # Otherwise, should return validated token
         token.set_exp()
-        self.assertEqual(self.backend.get_validated_token(str(token)).payload, token.payload)
+        self.assertEqual(
+            self.backend.get_validated_token(str(token)).payload, token.payload
+        )
 
         # Should not accept tokens not included in AUTH_TOKEN_CLASSES
         sliding_token = SlidingToken()
-        with override_api_settings(AUTH_TOKEN_CLASSES=(
-            'rest_framework_simplejwt.tokens.AccessToken',
-        )):
+        with override_api_settings(
+            AUTH_TOKEN_CLASSES=("rest_framework_simplejwt.tokens.AccessToken",)
+        ):
             with self.assertRaises(InvalidToken) as e:
                 self.backend.get_validated_token(str(sliding_token))
 
-            messages = e.exception.detail['messages']
+            messages = e.exception.detail["messages"]
             self.assertEqual(1, len(messages))
             self.assertEqual(
                 {
-                    'token_class': 'AccessToken',
-                    'token_type': 'access',
-                    'message': 'Token has wrong type',
+                    "token_class": "AccessToken",
+                    "token_type": "access",
+                    "message": "Token has wrong type",
                 },
                 messages[0],
             )
@@ -112,15 +118,17 @@ class TestJWTAuthentication(TestCase):
         # Should accept tokens included in AUTH_TOKEN_CLASSES
         access_token = AccessToken()
         sliding_token = SlidingToken()
-        with override_api_settings(AUTH_TOKEN_CLASSES=(
-            'rest_framework_simplejwt.tokens.AccessToken',
-            'rest_framework_simplejwt.tokens.SlidingToken',
-        )):
+        with override_api_settings(
+            AUTH_TOKEN_CLASSES=(
+                "rest_framework_simplejwt.tokens.AccessToken",
+                "rest_framework_simplejwt.tokens.SlidingToken",
+            )
+        ):
             self.backend.get_validated_token(str(access_token))
             self.backend.get_validated_token(str(sliding_token))
 
     def test_get_user(self):
-        payload = {'some_other_id': 'foo'}
+        payload = {"some_other_id": "foo"}
 
         # Should raise error if no recognizable user identification
         with self.assertRaises(InvalidToken):
@@ -132,7 +140,7 @@ class TestJWTAuthentication(TestCase):
         with self.assertRaises(AuthenticationFailed):
             self.backend.get_user(payload)
 
-        u = User.objects.create_user(username='markhamill')
+        u = User.objects.create_user(username="markhamill")
         u.is_active = False
         u.save()
 
@@ -154,7 +162,7 @@ class TestJWTTokenUserAuthentication(TestCase):
         self.backend = authentication.JWTTokenUserAuthentication()
 
     def test_get_user(self):
-        payload = {'some_other_id': 'foo'}
+        payload = {"some_other_id": "foo"}
 
         # Should raise error if no recognizable user identification
         with self.assertRaises(InvalidToken):
